function []=update_plots(subp_speed,curr_speed,subp_clutch,clutch_pos,subp_gear,curr_gear,t)
%UPDATE_PLOTS Função para fazer update aos três plots da interface gráfica,
%             da velocidade, da mudança e da embraiagem.
%##########################################################################
% Esta função faz o update dos três plots gráficos da interface.
%
% INPUTS:
% subp_speed -> Handle gráfico do subplot onde é representado o gráfico da
%               velocidade;
% curr_speed -> Valor da velocidade actual;
% subp_clutch -> Handle gráfico do subplot onde é representado o gráfico do
%                estado da embraiagem;
% clutch_pos -> Valor da posição da embraiagem;
% subp_gear -> Handle gráfico do subplot onde é representada a mudança
%              actual;
% curr_gear -> Valor da mudança actual;
% t -> Iteração temporal actual.
%
% OUTPUTS:
% N/A
%##########################################################################
% Actualização do gráfico das velocidades:
% Chama o subplot respectivo:
subplot(subp_speed)
% Plot da velocidade:
plot(t,curr_speed,'*r')
% Se o programa estiver a correr pela rpimeira vez, acrescenta o titulo:
if(t==0)
    % Liga a grelha:
    grid on
end
% Escreve o titulo so subplot:
title(sprintf('Speed: %0.0f[kh/h]',curr_speed));
% Calculo dos eixos usados:
axis([t-20,t+20,-50,170])
% Acumula os pontos no plot:
hold on
% Chama o subplot respectivo:
% Actualização do gráfico da embraiagem
subplot(subp_clutch)
% Plot da velocidade:
plot(t,clutch_pos,'*c')
% Se o programa estiver a correr pela rpimeira vez, acrescenta o titulo:
if(t==0)
    % Liga a grelha:
    grid on
end
% Escreve o titulo so subplot:
title(sprintf('Clutch: %0.0f',clutch_pos));
% Calculo dos eixos usados:
axis([t-20,t+20,0,1])
% Acumula os pontos no plot:
hold on
% Actualização do gráfico das mudanças:
% Chama o subplot respectivo:
% Se necessário, efectua-se uma coreecção ao valor da marcha-atrás:
if curr_gear==6
    ploted_gear=-1;
else
    ploted_gear=curr_gear;
end
subplot(subp_gear)
% Plot da velocidade:
plot(t,ploted_gear,'*b')
% Se o programa estiver a correr pela rpimeira vez, acrescemnta o titulo:
if(t==0)
    % Liga a grelha:
    grid on
end


% Escreve o titulo so subplot:
title(sprintf('Gear: %0.0f',ploted_gear));
% Calculo dos eixos usados:
axis([t-20,t+20,-1,5])
% Acumula os pontos no plot:
hold on
end